#!/bin/bash

# bibtex8 and bibtexu work but make errors, bibtex is the best
# the only problem it does not place Russian references first
# so please do it manually in *.bbl file (it is done here)
bibtex rubibtex-ex-x.aux
